@@ -1,5 +1,5 @@
 # ~/NMCog/nmcog/spinnaker/cognitivemap/__init__.py
 
-from .nealcogmap import NEALCogmap
+from .nealplacesystem import NEALPlaceSystem
 
 
